LuaAutoDoc constructor

LuaAutoDoc(
  1. String title, {
  2. String? version,
  3. String? dateTimeFormat,
  4. bool showSidebarIndex = false,
  5. String js = prism.js,
  6. String css = prism.css,
})

Construct an autodoc instance with title and version subtext. By default showDateTime is false. If set to true, a datetime stamp stub will appear near the title of the ToC. By default both js and css use prism.js and prism.css contents respectively. You can replace these and they will populate the output HTML and tags with their corresponding contents.

Implementation

LuaAutoDoc(
  this.title, {
  this.version,
  this.dateTimeFormat,
  this.showSidebarIndex = false,
  this.js = prism.js,
  this.css = prism.css,
});