dateTimeFormat property
Optional date time of document generation. If this is set, datetime will appear in the html output formatted using the intl package DateFormat specification: https://pub.dev/documentation/intl/latest/intl/DateFormat-class.html
Implementation
final String? dateTimeFormat;