popPath method
Removes the last id from the anchor path stack. Returns the anchor tag string value of the updated path.
Implementation
String popPath() {
if (_anchorPath.isNotEmpty) {
_anchorPath.removeLast();
}
return _anchorPath.join('.');
}