pushPath method

String pushPath(
  1. String label
)

Deeply nested tables will have their paths preserved to construct anchor tags. This will also return the current anchor tag string value.

See popPath.

Implementation

String pushPath(String label) {
  _anchorPath.add(label);
  return _anchors.putIfAbsent(label, () => _anchorPath.join('.'));
}