showSidebarIndex property

bool showSidebarIndex
final

Optional flag to move the index into a sidebar on the page that sticks to the reader's screen while they scroll. This will also remove the floating carrot button that normally takes the user to the top of the page where the index was.

The header information for the doc generation (title, version, date) will be place in a toolbar at the top.

Implementation

final bool showSidebarIndex;