docs/prism library

Constants

css → const String
This combines the generated css and adds additional styling to be used in the final html output documentation.
js → const String
This is generated js.