css top-level constant

String const css

This combines the generated css and adds additional styling to be used in the final html output documentation.

Implementation

const css =
    '''
        $_css

        html {
          background-color: #F8F8F8 ;
        }

        h1, h2, h3, h4, h5, .version-info {
          color: #000080;
          font-family: Verdana, Geneva, sans-serif;
          font-weight: normal;
          font-style: normal;
          text-align: left;
        }

        a:link {
          color: #000080;
        }

        a:link:hover {
          background-color: #D0D0FF;
          color: #000080;
          border-radius: 4px;
        }

        code {
          font-size: 12pt;
        }

        body {
          background-color: #FFFFFF ;
          color: #000000 ;
          font-family: Helvetica, Arial, sans-serif ;
          text-align: justify ;
          line-height: 1.25 ;
          margin: 16px auto ;
          padding: 32px ;
          border: solid #ccc 1px ;
          border-radius: 20px ;
          max-width: 70em ;
          width: 90% ;
        }

        #floater {
          position: fixed;
          top: 0%;
          right: 50%;
          z-index: 1;
        }
        ''';