Evaluator class

A very simple LUA evaluator using a basic implementation of the standard runtime StdRuntime. Can be used whereever EvaluatorMixin is expected. If someone wants to get started using this library this is what they want to use.

Mixed-in types

Constructors

Evaluator()

Properties

errors List<String>
Forward to StdRuntimeResults.errors and returns as a List.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
impl StdRuntime
latefinal
results StdRuntimeResults
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearResults() → void
The results field is intended to be used to collect runtime information while evaluating scripts or performing extra passes on IR. In REPL, we need to clear the results so as to not populate the console with older messages.
defGlobal(LuaObject value) LuaObject
Forward to StdRuntime.defGlobal.
defLocal(LuaObject value) LuaObject
Forward to StdRuntime.defLocal.
findVar(String id) LuaObject?
Forward to StdRuntime.findVar.
findVarArgs() List<LuaObject>?
Forward to StdRuntime.findVarArgs.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
visitAST(AST ast) Object?
Forward to StdRuntime.visitAST.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited