StdRuntimeResults class

Standard runtime results collects no special information.

Inheritance

Constructors

StdRuntimeResults()

Properties

errors Set<String>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
infos Set<String>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warns Set<String>
finalinherited

Methods

addAllDiagnostics(List<String> infos) → void
inherited
addAllErrors(List<String> errors) → void
inherited
addAllWarnings(List<String> warns) → void
inherited
addDiagnostic(String info) → void
inherited
addError(String error) → void
inherited
addWarning(String warn) → void
inherited
clear() → void
Wipes the instance of all collected results for re-use.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited