StreamChar class

Constructors

StreamChar(String lexeme, StreamPos pos)
const
StreamChar.eof()
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
lexeme String
final
pos StreamPos
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy({String? lexeme, StreamPos? pos}) StreamChar
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sameLexeme(StreamChar char) bool
toString() String
A string representation of this object.
inherited
toToken(TokenType type, {String? lexeme}) Token

Operators

operator ==(Object other) bool
The equality operator.
override