StreamPos class

Constructors

StreamPos(int col, int row)
const

Properties

col int
final
hashCode int
The hash code for this object.
no setteroverride
isEOF bool
no setter
isSynthesized bool
no setter
row int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
synthetic bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

eof StreamPos
no setter
synthesized StreamPos
no setter