Token class

Constructors

Token(TokenType type, String lexeme, StreamPos pos)
Token.eof()
Token.fromStreamChar(TokenType type, StreamChar char)
Token.raw(String lexeme, StreamPos pos)
Token.synthesized(String lexeme, {TokenType? type})

Properties

hashCode int
The hash code for this object.
no setterinherited
isEOF bool
no setter
lexeme String
final
pos StreamPos
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TokenType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited