TokenType enum

Inheritance
Available extensions

Values

kRaw → const TokenType
kNewLine → const TokenType
kFunc → const TokenType
kEnd → const TokenType
kLParen → const TokenType
kRParen → const TokenType
kLBracket → const TokenType
kRBracket → const TokenType
kLCurly → const TokenType
kRCurly → const TokenType
kDot → const TokenType
kComma → const TokenType
kSpread → const TokenType
kConcat → const TokenType
kString → const TokenType
kSemicolon → const TokenType
kColon → const TokenType
kSelf → const TokenType
kLocal → const TokenType
kAssign → const TokenType
kEQ → const TokenType
kLT → const TokenType
kLTE → const TokenType
kGT → const TokenType
kGTE → const TokenType
kNEQ → const TokenType
kTrue → const TokenType
kFalse → const TokenType
kNumber → const TokenType
kAdd → const TokenType
kSub → const TokenType
kMult → const TokenType
kCarrot → const TokenType
kHash → const TokenType
kMod → const TokenType
kDiv → const TokenType
kDivFloor → const TokenType
kIf → const TokenType
kElseIf → const TokenType
kElse → const TokenType
kFor → const TokenType
kUntil → const TokenType
kWhile → const TokenType
kRepeat → const TokenType
kBreak → const TokenType
kIn → const TokenType
kDo → const TokenType
kNil → const TokenType
kAnd → const TokenType
kOr → const TokenType
kNot → const TokenType
kThen → const TokenType
kReturn → const TokenType
kBlockComment → const TokenType
kLineComment → const TokenType
kBitNot → const TokenType
kBitAnd → const TokenType
kBitOr → const TokenType
kGoto → const TokenType
kGotoLabel → const TokenType
kEOF → const TokenType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TokenType>
A constant List of the values in this enum, in order of their declaration.