loopDepth property

int loopDepth
getter/setter pair

If loopDepth > 0 we are in a loop construct and can break. This is used to detect the correctness of the "break" keyword.

Implementation

int loopDepth = 0;