lua/visitors/bindings/std library

Classes

CoroutineCallbacks
If one implementation for coroutines are needed, then all implementations for the coroutine API are needed. This class provides a quick configuration for all methods.

Mixins

Std
Implements the lua standard libraries. Some implementations need further defining by the programmer such as Std.onRequireImpl called in initStdRequire.

Constants

catRuntime → const String

Typedefs

StdPrintCallback = void Function(String)