onCoroutineCreate property

int Function(LuaObject fn) onCoroutineCreate
getter/setter pair

This is called by the closure defined in initStdCoroutines. The callback expects a LuaObject argument which will have satisfied LuaObject.isFunc. The implementation expected to return an int address value of the designated coroutine.

Implementation

int Function(LuaObject fn) onCoroutineCreate;