onCoroutinePopScope property
Handle the scope pop to collect the stack information
via BaseRuntime.coCtrlStruct before it is set to null.
Implementation
void Function(CoCtrlStruct) onCoroutinePopScope;
Handle the scope pop to collect the stack information
via BaseRuntime.coCtrlStruct before it is set to null.
void Function(CoCtrlStruct) onCoroutinePopScope;