onCoroutineYield property
Given a list of lua value args, perform the coroutine
yield behavior.
Implementation
LuaArgPack Function(List<LuaObject> args) onCoroutineYield;
Given a list of lua value args, perform the coroutine
yield behavior.
LuaArgPack Function(List<LuaObject> args) onCoroutineYield;