findVar method

LuaObject? findVar(
  1. String id
)
inherited

Searches for a variable with the identifier id in the current scope. The implementation details also searches the parents in order if not found locally until such an id is found.

If no id is found, null is returned signifying no such variable with that id exists.

Implementation

LuaObject? findVar(String id) {
  return scope.findVar(id);
}