onRequireImplComplete property

void Function(String)? onRequireImplComplete
getter/setter pair

This is called by the closure defined in initStdRequire after the call to Std.onRequireImpl. In this way, programmers can configure the implementation details of require on a case-by-case basis (if needed) while still performing general book keeping for each.

Implementation

void Function(String)? onRequireImplComplete;