lua/visitors/runtime/base
library
Classes
-
BaseResults
-
The result of processing a lua script can omit
errors, warnings, or custom diagnostic info.
This results class collects such information at run-time
and it is up to the user to decide when to reveal the
information to the user.
-
BaseRuntime
-
Implements common Lua runtime logic.
Extend with mixin ReturnStmtCallStackUnwind
or ReturnStmtDoNotUnwind.
-
ControlStructure
-
Whenever a language construct would move the program's execution
out of the normal tree walk, we can refer to this structure and obtain
the exact location to resume. See: Coroutines.
-
RuntimeCallbacks
-
A configuration class enabling the programmer to
define what happens onErrors, onWarnings, or
onDiagnostics.