BaseResults class abstract

The result of processing a lua script can omit errors, warnings, or custom diagnostic info. This results class collects such information at run-time and it is up to the user to decide when to reveal the information to the user.

You must extend this so that you can add your own diagnostic information or even use it to lift other data from the AST.

Constructors

BaseResults()

Properties

errors Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
infos Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warns Set<String>
final

Methods

addAllDiagnostics(List<String> infos) → void
addAllErrors(List<String> errors) → void
addAllWarnings(List<String> warns) → void
addDiagnostic(String info) → void
addError(String error) → void
addWarning(String warn) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited