copy method
Makes a new pointer with the data at some point in time.
Implementation
CoCtrlStruct copy() => CoCtrlStruct(
node,
counter: counter,
end: end,
stmtIdx: stmtIdx,
iter: iter,
);
Makes a new pointer with the data at some point in time.
CoCtrlStruct copy() => CoCtrlStruct(
node,
counter: counter,
end: end,
stmtIdx: stmtIdx,
iter: iter,
);