ControlStructure class

Whenever a language construct would move the program's execution out of the normal tree walk, we can refer to this structure and obtain the exact location to resume. See: Coroutines.

Constructors

ControlStructure(Stmt node, {num? counter, num? end, Function? iter})

Properties

counter num
The counter in the control structure's body if applicable.
getter/setter pair
end num
The end of the counter in the control structure if applicable.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iter Function?
The iterator function for the control structure if applicable.
getter/setter pair
node Stmt
The control structure node in the tree.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited