TraceCallback typedef
The function type to respond to the scope being unwound. When reporting errors. See RuntimeCallbacks.
Implementation
typedef TraceCallback = void Function(Set<String>);
The function type to respond to the scope being unwound. When reporting errors. See RuntimeCallbacks.
typedef TraceCallback = void Function(Set<String>);