lua/visitors/runtime/luaobject library

Classes

LuaDoc
The configuration class for LuaObject.doc instances. To add documentation use the LuaDoc constructor. Provide a category and the generated docs will group it with those objects sharing the same category. To omit the LuaObject from the generated docs, use LuaDoc.skip.
LuaFuncBuilder
This class provides an API for effortlessly constructing lua function objects.
LuaObject
LuaObjectNoSemantics
Represents a lua object for analyzing irregardless if it is a well-defined variable or value. This permits any visitor to look pass semantic errors and continue marching through the grapheme.
LuaReturnValueException
A type to represent if the callstack was unwound b/c of the luareturn keyword. Stores the value of the operation to unpack. See ReturnStmtCallStackUnwind and ReturnStmtDoNotUnwind.

Enums

LuaType
Strong type enumerations for all possible lua primitives.

Extensions

Native2Lua on Object
A convenience utility on Object to construct LuaObject instances in-place.

Typedefs

LuaFieldsMap = Map<String, LuaObject?>
Shorthand notation for a Map of String and LuaObject key-pairs. Note that the LuaObject can be null as lua represents these as LuaType.nil.