unpack method
Lua multiargs returned by functions whose length is of size 1 can be unpacked into a single lua object.
Implementation
LuaObject? unpack() {
if (isNotEmpty) {
return first;
}
return LuaObject.nil('<argpack>');
}
Lua multiargs returned by functions whose length is of size 1 can be unpacked into a single lua object.
LuaObject? unpack() {
if (isNotEmpty) {
return first;
}
return LuaObject.nil('<argpack>');
}