LuaBreakStmtException class
A type to represent if the callstack was unwound b/c of
the lua break keyword. A break statement can only
be inside a loop construct like for, while, and repeat.
The parser must report a break statement outside of a loop
so the runtime can bubble up out of the construct safely while
visiting all loop nodes.
Not treated as an actual exception or error.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited