LuaObject.nil constructor
LuaObject.nil(
- String id
Constructs a lua object with null values and fields.
Implementation
LuaObject.nil(this.id);
Constructs a lua object with null values and fields.
LuaObject.nil(this.id);