isFunc property
bool
get
isFunc
Query if this lua object is a table and has a field named '__call'.
Implementation
bool get isFunc => isTable && readField('__call') != null;
Query if this lua object is a table and has a field named '__call'.
bool get isFunc => isTable && readField('__call') != null;