isTruthy property
bool
get
isTruthy
In lua, all values have a truthyness which means they can be used in conditional statements. If value is null or false, then the result is false. All other values and the result is true. If this lua object is a table, then the result is true.
Implementation
bool get isTruthy => switch (isRef) {
true => deref().isTruthy,
false => switch (isTable) {
false => switch (_value) {
null || false => false,
_ => true,
},
true => true,
},
};