LuaReturnValueException class
A type to represent if the callstack was unwound b/c of
the luareturn keyword. Stores the value of the operation
to unpack. See ReturnStmtCallStackUnwind and
ReturnStmtDoNotUnwind.
Not treated as an actual exception or error.
Constructors
- LuaReturnValueException(LuaObject value)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited