LuaThread class
A type that represents a lua thread. It only stores the address addr used by the evaluator. This type is used to distinguish a LuaObject.value from other types.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited