popScope method
void
popScope()
Pops scope and restores current to the previous scope Scope.parent;
Implementation
void popScope() {
if(current.parent != null) {
current = current.parent!;
}
}
Pops scope and restores current to the previous scope Scope.parent;
void popScope() {
if(current.parent != null) {
current = current.parent!;
}
}