resetNextIdFrom method

void resetNextIdFrom(
  1. Scope other
)

Clears _nextId and copies the contents of the other's own nextId. This should be used with caution as the two scopes could shadow variables where this is not wanted.

Implementation

void resetNextIdFrom(Scope other) {
  _nextId..clear()..addAll(other._nextId);
}