AssignExpr class

Variables can be reassigned. This node encodes this operation. While technically a binary operation by its format, a rewrite required that it was evaluated in a different grammar rule. Maybe in the future this encoding will be corrected.

Inheritance

Constructors

AssignExpr(Token op, {required Stmt lhs, required Stmt rhs})

Properties

hashCode int
The hash code for this object.
no setterinherited
lhs Stmt
final
op Token
final
rhs Stmt
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited