AssignMultiExpr class

Like DeclMultiVar, multiple variables can be reassigned at once.

Inheritance

Constructors

AssignMultiExpr.resize(Token op, {required List<Stmt> lhs, required List<Stmt> rhs})
See: https://www.lua.org/manual/5.5/manual.html#3.4.12
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lhs List<Stmt>
final
op Token
final
rhs List<Stmt>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited