AssignMultiStmt class
Like DeclMultiVar, multiple variables can be reassigned at once. Note that it is not a math expr and cannot be used to return assignments as values.
Constructors
-
AssignMultiStmt.resize(Token op, {required List<
Stmt> lhs, required List<Stmt> rhs}) -
See: https://www.lua.org/manual/5.5/manual.html#3.4.12
factory
Properties
Methods
-
accept<
R> (Visitor< R> v) → R -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited