AssignStmt class
Variables can be reassigned. This node encodes this operation. Note that it is not a math expr and cannot be used to return assignments as values.
Constructors
- AssignStmt(Token token, {required Stmt lhs, required Stmt rhs})
Properties
Methods
-
accept<
R> (Visitor< R> v) → R -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited