BinaryExpr class

Any binary expression (lhs op rhs) is encoded by this node. op is the operator used on lhs and rhs expressions.

Inheritance

Constructors

BinaryExpr(Token op, {required MathExpr lhs, required MathExpr rhs})

Properties

hashCode int
The hash code for this object.
no setterinherited
lhs MathExpr
final
op Token
final
rhs MathExpr
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited