isOptional property
Optional parameters must be last. Undefined behavior will follow if this rule is not.
Implementation
final bool isOptional;
Optional parameters must be last. Undefined behavior will follow if this rule is not.
final bool isOptional;