DeclMultiVar class
Lua supports multivariable assignment. Therefore it supports multivariable declarations. The values are determined at runtime and follow the specification here: https://www.lua.org/pil/5.1.html
Constructors
-
DeclMultiVar.initNils(List<
Token> vars, List<Token?> attrs, [bool local = false]) -
Convenience constructor.
See DeclVar.
factory
-
DeclMultiVar.initVals(List<
Token> vars, List<Token?> attrs, List<MathExpr> vals, [bool local = false]) -
Transforms tokens into DeclVar statements forwarding
the corresponding
attrsandvaluselement each.factory
Properties
Methods
-
accept<
R> (Visitor< R> v) → R -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited