DeclVar class

This represents a variable declaration in lua. The variable name will be id. It may have initialization terms provided by init.

Inheritance

Constructors

DeclVar.initNil(Token id)
Convenience to construct nil lua grammar node.
DeclVar.initValue(Token id, {required MathExpr value})
Constructor expects a value. If constructing a nil variable, see DeclVar.initNil.

Properties

hashCode int
The hash code for this object.
no setterinherited
id Token
final
init MathExpr?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited