ForIterLoopStmt class

The generic variant of lua's for-loop control structure. Unlike the step-wise variant, this evaluates exprs and stores them in vars following the multi-variable assignment rules in this language. That is, if there are too many returned results and not enough vars, then the remaining vars will be nil.

Inheritance

Constructors

ForIterLoopStmt(Token token, {required List<Token> vars, required List<MathExpr> exprs, required List<Stmt> body})

Properties

body List<Stmt>
The body of code to visit.
final
exprs List<MathExpr>
The list of expressions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
getter/setter pairinherited
vars List<Token>
The list of variables.
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited