ForLoopStmt class

The step-wise variant of lua's for-loop control structure.

Inheritance

Constructors

ForLoopStmt(Token token, {required AssignExpr control, required MathExpr endExpr, required MathExpr stepExpr, required List<Stmt> body})

Properties

body List<Stmt>
The body of code to visit.
final
control AssignExpr
The control term begins as an assignment.
final
endExpr MathExpr
Step-wise for-loops increase by stepExpr and the body executes until control reaches or exceeds endExpr.
final
exprList List<MathExpr>
Convenience method to return all non-null expressions.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepExpr MathExpr
Step-wise for-loops increase by stepExpr and the body executes until control reaches or exceeds endExpr.
final
token Token
The lexeme and pos in the doc.
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited