GotoLabelStmt class

Represents labels which goto statements use.

Inheritance

Constructors

GotoLabelStmt(Token label)

Properties

hashCode int
The hash code for this object.
no setterinherited
label Token
The Name for the jump.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited