GotoStmt class

Represents the 'goto' keyword in lua. https://www.lua.org/manual/5.5/manual.html#3.3.4

Inheritance

Constructors

GotoStmt(RawExpr expr)

Properties

expr RawExpr
The Name to jump to.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited