IfStmt class

Represents a linked list of conditional statements. Consider the chain if -> elif -> elif -> else. Therefore else statements are IfStmt without an expr. See IfStmt.terminalElse constructor.

Inheritance

Constructors

IfStmt(Token token, {required MathExpr expr, required List<Stmt> body, IfStmt? nextIfStmt})
IfStmt.terminalElse(Token token, {required List<Stmt> body})

Properties

body List<Stmt>
final
expr MathExpr?
final
hashCode int
The hash code for this object.
no setterinherited
isTerminalElse bool
final
nextIfStmt IfStmt?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
The lexeme and pos in the doc.
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited