RawExpr class

Represents identifiers in lua. Anything that is not a keyword or an expression is likely an identifier like a variable name or table fields. The spec defines labels as identifiers but those are encoded in this lib by GotoLabelStmt.

Inheritance

Constructors

RawExpr(Token token)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited