RepeatUntilLoopStmt class

Similar to a while-loop but conditional expression untilExpr is the termination condition.

Inheritance

Constructors

RepeatUntilLoopStmt(Token token, {required MathExpr untilExpr, required List<Stmt> body})

Properties

body List<Stmt>
The body of code to visit.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
The lexeme and pos in the doc.
final
untilExpr MathExpr
Termination condition expression.
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited