StringLiteral class

String literals are encoded as this node.

Inheritance

Constructors

StringLiteral(Token token, {required String value})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
final
value String
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited