TableLiteral class

Table literal expressions {...} are encoded by this node.

Inheritance

Constructors

TableLiteral(Token token, {required List<KeyValStmt> pairs})

Properties

hashCode int
The hash code for this object.
no setterinherited
pairs List<KeyValStmt>
Tables may have zero or more KeyValStmt pairs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited