UnaryExpr class

Any tightly bound unary prefix is encoded by this node.

Inheritance

Constructors

UnaryExpr(Token prefix, {required MathExpr rhs})

Properties

hashCode int
The hash code for this object.
no setterinherited
prefix Token
final
rhs MathExpr
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited