WhileLoopStmt class

Lua while-do loop grammar node.

Inheritance

Constructors

WhileLoopStmt(Token token, {required MathExpr expr, required List<Stmt> body})

Properties

body List<Stmt>
The body of code to visit if expr is truthy.
final
expr MathExpr
The conditional.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
The lexeme and pos in the doc.
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited