GzGraph class
Represents the graph block in DOT language.
Introduces new getters GzGraph.stubHeaders
and GzGraph.stubBody which fill the graph
with nodes and links them together respectively.
GzGraph.toString is implemented to return a graph block.
- Inheritance
-
- Object
- GzBaseNode
- GzGraph
- Implementers
Constructors
Properties
-
children
↔ List<
GzBaseNode> -
getter/setter pairinherited
- color ↔ String?
-
getter/setter pairinherited
- fontColor ↔ String?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- key ↔ int
-
latefinalinherited
- label ↔ String
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape ↔ String?
-
getter/setter pairinherited
- stubAttrs → String
-
Constructs the full attribute DOT lang syntax separated by space.
no setterinherited
- stubBody → String
-
Populate the graph with nodes.
no setter
- stubColor → String
-
Constructs a string stub for the color, if one is provided
and non-null.
no setterinherited
- stubfontColor → String
-
Constructs a string stub for the fontColor, if one is provided
and non-null.
no setterinherited
- stubHeaders → String
-
Link nodes together. Introduces the "self" node
representing the start of a new graph.
no setter
- stubId → String
-
no setterinherited
- stubLabel → String
-
Constructs the string stub for the label, if one is provided
and non-empty.
no setterinherited
- stubShape → String
-
Constructs a string stub for the shape, if one is provided
and non-null.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited