css property
The custom css script contents. Each lua entry will have a
tag pair and a css class with which to identify the lua object type for further styling.Lua objects or tables will have the css class "lua-table".
Lua functions will have the css class "lua-func".
All other lua variables (fields and globals) will have the css class "lua-field".
Implementation
final String css;