clearResults method
void
clearResults()
The results field is intended to be used to collect runtime information while evaluating scripts or performing extra passes on IR. In REPL, we need to clear the results so as to not populate the console with older messages.
Implementation
void clearResults() => results.clear();