Parser class

Constructors

Parser(List<Token> tokens)

Properties

curr int
getter/setter pair
errors List<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokens List<Token>
final
warns List<String>
final

Methods

addError(String err) → void
addWarning(String warn) → void
advance() Token
advanceAndThen<T>(T then()) → T
analyze() AST
anyOf(List<TokenType> types) bool
argList({TokenType? terminal, List<TokenType>? terminals}) List<MathExpr>
assignExpr() AssignExpr
binaryExpr() MathExpr
bitwiseExpr() MathExpr
bodyStmt({TokenType? terminal, List<TokenType>? terminals}) List<Stmt>
breakStmt() Stmt
canMultAssignWith(MathExpr term) bool
compareExpr() MathExpr
consume(TokenType expected, String err) Token
declFuncExpr() FuncExpr
declMultiVarStmt() Stmt
eof() bool
factorExpr() MathExpr
falseExpr() MathExpr
forLoopStmt() Stmt
gotoLabelStmt() Stmt
gotoStmt() Stmt
groupExpr() MathExpr
ifStmt() IfStmt
ifStmtBranch(Token token) IfStmt
literal() MathExpr
localStmt() Stmt
logicalAndExpr() MathExpr
logicalOrExpr() MathExpr
math() MathExpr
memoryExpr() MathExpr
multiAssignExpr({required MathExpr first}) MathExpr
nilLiteral() MathExpr
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notExpr() MathExpr
numberLiteral() MathExpr
objectExpr() MathExpr
peek({int? offset}) Token
rawExpr() RawExpr
repeatUntilLoopStmt() Stmt
returnStmt() Stmt
selfExpr() MathExpr
stmt() Stmt?
stringLiteral() MathExpr
tableExpr() MathExpr
tablePairExpr() KeyValStmt
tablePairsList() List<KeyValStmt>
toString() String
A string representation of this object.
inherited
trueExpr() MathExpr
unaryExpr() MathExpr
whileLoopStmt() Stmt

Operators

operator ==(Object other) bool
The equality operator.
inherited