CoroutineCallbacks class
If one implementation for coroutines are needed, then all implementations for the coroutine API are needed. This class provides a quick configuration for all methods.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCoroutineCreate ↔ int Function(LuaObject fn)
-
This is called by the closure defined in
initStdCoroutines. The callback expects a LuaObject argument which will have satisfied LuaObject.isFunc. The implementation expected to return an int address value of the designated coroutine.getter/setter pair -
onCoroutineResume
↔ LuaObject Function(int addr, List<
LuaObject> vargs) -
Given a coroutine int address and optional
vargs, resume that coroutine and return a value. Multiple values will be unpacked by the runtime.getter/setter pair - onCoroutineStatus ↔ String Function(int addr)
-
Given a coroutine int address, return the status of the
coroutine as a String.
getter/setter pair
-
onCoroutineYield
↔ void Function(List<
LuaObject> args) -
Given a list of lua value
args, perform the coroutine yield behavior.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited