lua/visitors/runtime/base library
Classes
- BaseResults
- The result of processing a lua script can omit errors, warnings, or custom diagnostic info. This results class collects such information at run-time and it is up to the user to decide when to reveal the information to the user.
- BaseRuntime
- Implements common Lua runtime logic. Extend with mixin ReturnStmtCallStackUnwind or ReturnStmtDoNotUnwind.
- RuntimeCallbacks
- A configuration class enabling the programmer to define what happens onErrors, onWarnings, or onDiagnostics.
Mixins
- ReturnStmtCallStackUnwind
- Normal lua runtime behavior implementation for ReturnStmt.
- ReturnStmtDoNotUnwind
- Special lua runtime behavior suitable for static analysis of branching control flows.
Extensions
- ObjectAsTypeOrNull on Object
- Truthy on Object?
-
Helper to convert Object to a lua
trueorfalseequivalent used in boolean expressions.
Typedefs
-
TraceCallback
= void Function(Set<
String> ) - The function type to respond to the scope being unwound. When reporting errors. See RuntimeCallbacks.