BaseResults class abstract

Constructors

BaseResults()

Properties

errors Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
infos Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warns Set<String>
final

Methods

addAllDiagnostics(List<String> infos) → void
addAllErrors(List<String> errors) → void
addAllWarnings(List<String> warns) → void
addDiagnostic(String info) → void
addError(String error) → void
addWarning(String warn) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited