CoCtrlStruct class
NOTE: Incomplete coroutines. May be removed. Whenever a language construct would move the program's execution out of the normal tree walk, we can refer to this structure and obtain the exact location to resume.
Constructors
Properties
- counter ↔ num
-
The counter in the control structure's body if applicable.
getter/setter pair
- end ↔ num
-
The end of the counter in the control structure if applicable.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iter ↔ Function?
-
The iterator function for the control structure if applicable.
getter/setter pair
- node ↔ Stmt
-
The control structure node in the tree.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stmtIdx ↔ int
-
The child node offset in the control structure.
Often used with the body of some statement list.
getter/setter pair
Methods
-
copy(
) → CoCtrlStruct - Makes a new pointer with the data at some point in time.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited