LuaDoc class

The configuration class for LuaObject.doc instances. To add documentation use the LuaDoc constructor. Provide a category and the generated docs will group it with those objects sharing the same category. To omit the LuaObject from the generated docs, use LuaDoc.skip.

Constructors

LuaDoc({String? category, String? html, String keyValueHtml(Object value)?, bool exclude(Object value)?})
Custom configuration associated with some LuaObject.
LuaDoc.skip()
Configuration sets noHtml.

Properties

category String?
Which category the associated LuaObject belongs.
getter/setter pair
exclude bool Function(Object value)?
A helper function that filters what values or enums from your table will be present in the generated docs. This is useful if you must have symbols in your runtime but wish to exclude those from public documentations.
final
hashCode int
The hash code for this object.
no setterinherited
html String
The getter for _html which returns empty string if null.
getter/setter pair
includeHtml bool
The positive variant of noHtml.
no setter
keyValueHtml String Function(Object value)?
A helper function that maps a table's primitive fields to their html documentation. This is useful if your lua object contains fields that are not LuaObjects such as int or bool. The auto doc will print them as-is without further inspection. Using this helper will produce additional documentation.
final
noHtml bool
Whether or not the LuaObject associated should be rendered out to html.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited