exclude property
A helper function that filters what values or enums from your table will be present in the generated docs. This is useful if you must have symbols in your runtime but wish to exclude those from public documentations.
Implementation
final bool Function(Object value)? exclude;