isPrintable property
bool
get
isPrintable
Query if std "print" can print the value. This is short for asking if the lua object is a table or a function, which would return the address in the VM at runtime for this lua obejct.
Implementation
bool get isPrintable => switch (isRef) {
true => deref().isPrintable,
false => !isTable && !isFunc,
};