writeFields method
A convenience utility to write all fields from some input table.
Implementation
void writeFields(LuaTable table) {
final ref = deref();
for (final f in table.entries) {
ref.writeField(f.key, f.value);
}
}
A convenience utility to write all fields from some input table.
void writeFields(LuaTable table) {
final ref = deref();
for (final f in table.entries) {
ref.writeField(f.key, f.value);
}
}