LuaReturnValueException class

A type to represent if the callstack was unwound b/c of the lua return keyword. Stores the value of the operation to unpack. See ReturnStmtCallStackUnwind and ReturnStmtDoNotUnwind.

Not treated as an actual exception or error.

Constructors

LuaReturnValueException(List<LuaObject> argpack)

Properties

argpack List<LuaObject>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited