Native2Lua extension

A convenience utility on Object to construct LuaObject instances in-place.

See Object.toLua.

on

Methods

makeLuaRef() LuaObject?

Available on Object, provided by the Native2Lua extension

Attempts to return the underlying LuaObject of this to be used as a direct handle or reference. Otherwise null is returned.
toLua(String id) LuaObject

Available on Object, provided by the Native2Lua extension

A new LuaObject.variable instance is returned whose variable name in scope is id.
toLuaRet() LuaObject

Available on Object, provided by the Native2Lua extension

Calls toLua with the id of "ret" which is short for "return". The helps track return values.