toLua method
A new LuaObject.variable instance
is returned whose variable name in scope is id.
Implementation
LuaObject toLua(String id) => switch (this) {
final LuaFieldsMap m => LuaObject.table(id, m),
_ => LuaObject.variable(id, this),
};
A new LuaObject.variable instance
is returned whose variable name in scope is id.
LuaObject toLua(String id) => switch (this) {
final LuaFieldsMap m => LuaObject.table(id, m),
_ => LuaObject.variable(id, this),
};