Scope class

Constructors

Scope({Scope? parent, LuaObject? context})

Properties

context LuaObject?
final
depth int
final
hasContext bool
no setter
hashCode int
The hash code for this object.
no setterinherited
parent Scope?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vars Map<String, LuaObject>
final

Methods

defVar(String id, Object? value) LuaObject
dump() → void
findVar(String id) LuaObject?
findVarArgs() List<LuaObject>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

randId() String