AssignExpr class
Variables can be reassigned. This node encodes this operation. While technically a binary operation by its format, a rewrite required that it was evaluated in a different grammar rule. Maybe in the future this encoding will be corrected.
Constructors
- AssignExpr(Token op, {required Stmt lhs, required Stmt rhs})
Properties
Methods
-
accept<
R> (Visitor< R> v) → R -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited