BinaryExpr class
Any binary expression (lhs op rhs) is encoded by this node. op is the operator used on lhs and rhs expressions.
Constructors
- BinaryExpr(Token op, {required MathExpr lhs, required MathExpr rhs})
Properties
Methods
-
accept<
R> (Visitor< R> v) → R -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited