DeclArg class
This node tells the grammar how to compose a function's argument list.
If a parameter isOptional, then the runtime won't include its cound in the call expression.
Additionally. isOptional will decorate this parameter in the generated docs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Token
-
The name of this parameter.
This is also the lexeme and pos in the doc.
final
- isOptional → bool
-
Optional parameters must be last.
Undefined behavior will follow if this rule is not.
final
- lexeme → String
-
Shorthand for
id.lexeme.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept<
R> (Visitor< R> v) → R -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited