DeclMultiVar class

Lua supports multivariable assignment. Therefore it supports multivariable declarations.

Inheritance

Constructors

DeclMultiVar.initNils(List<Token> tokens)
Convenience constructor. See DeclVar.
factory
DeclMultiVar.initVars(List<Token> tokens, List<MathExpr> values)
Constructs a multivariable assignment expression from a list of values. If there are more tokens than there are values, then the remaining vars will be associated with DeclVar.initNil.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vars List<DeclVar>
The list of DeclVar nodes.
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited