DeclMultiVar class
Lua supports multivariable assignment. Therefore it supports multivariable declarations.
Constructors
-
DeclMultiVar.initNils(List<
Token> tokens) -
Convenience constructor.
See DeclVar.
factory
-
DeclMultiVar.initVars(List<
Token> tokens, List<MathExpr> values) -
Constructs a multivariable assignment expression
from a list of
values. If there are moretokensthan there arevalues, then the remaining vars will be associated with DeclVar.initNil.factory
Properties
Methods
-
accept<
R> (Visitor< R> v) → R -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited