DeclMultiVar class

Lua supports multivariable assignment. Therefore it supports multivariable declarations. The values are determined at runtime and follow the specification here: https://www.lua.org/pil/5.1.html

Inheritance

Constructors

DeclMultiVar.initNils(List<Token> vars)
Convenience constructor. See DeclVar.
factory
DeclMultiVar.initVals(List<Token> vars, List<MathExpr> vals)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
getter/setter pairinherited
vals List<MathExpr>
final
vars List<DeclVar>
The list of DeclVar nodes.
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited