DeclVar class

This represents a variable declaration in lua. The variable name will be id. It may have initialization terms provided by init.

Inheritance

Constructors

DeclVar.initNil(Token token, {Token? attr})
Convenience to construct nil lua grammar node.
DeclVar.initValue(Token token, {required MathExpr value, Token? attr})
Constructor expects a value. If constructing a nil variable, see DeclVar.initNil.

Properties

attr Token?
An optional attribute given to this variable.
final
hashCode int
The hash code for this object.
no setterinherited
id Token
Shorthand to abtain the underlining id lexeme.
no setter
init MathExpr?
The MathExpr to eval and assign to this variable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
getter/setter pairinherited

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited