ForIterLoopStmt class

The key-value variant of lua's for-loop control structure. Unlike the step-wise variant, this destructures iterExpr into key and value in each loop until there's nothing left to destructure.

Inheritance

Constructors

ForIterLoopStmt(Token token, {required Token key, required Token value, required MathExpr iterExpr, required List<Stmt> body})

Properties

body List<Stmt>
The body of code to visit.
final
hashCode int
The hash code for this object.
no setterinherited
iterExpr MathExpr
The iterator to advanced and destructure.
final
key Token
The key lexeme to be introduced in scope.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
The lexeme and pos in the doc.
final
value Token
The value lexeme to be introduced in scope.
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited