KeyValStmt class
For convenience, table {key, value} expressions
are encoded as this node.
Constructors
- KeyValStmt(Token token, {required MathExpr key, required MathExpr value})
-
Constructs the pair with a given
key. - KeyValStmt.autokey(Token token, MathExpr value)
- Constructs the pair without a key. Lua assigns an integer key in this situation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → MathExpr?
-
Lua table entries have implied keys if none are provided.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token ↔ Token
-
getter/setter pairinherited
- value → MathExpr
-
The value part of the pair.
final
Methods
-
accept<
R> (Visitor< R> v) → R -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited