MemoryAccess class

Memory access node encodes which operator op was used, the callee resolved on the left-hand side, the type for convenience, and the input args.

Inheritance

Constructors

MemoryAccess.call(Token op, MathExpr callee, List<MathExpr> args)
Constructor to encode function calls on callee with args.
MemoryAccess.field(Token op, MathExpr callee, MathExpr field)
Constructor to encode field access on a var callee.
MemoryAccess.table(Token op, MathExpr callee, MathExpr key)
Constructor to encode table lookup by key on callee.

Properties

args List<MathExpr>
final
callee MathExpr
final
field MathExpr?
If this grammar is used to obtain a field, then the first entry of args has the field.
no setter
hashCode int
The hash code for this object.
no setterinherited
op Token
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MemoryAccessType
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited