SelfExpr class

The token for 'self'. While not a keyword in lua, it is encoded as one in this lib for convenience.

Inheritance

Constructors

SelfExpr(Token token)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Token
final

Methods

accept<R>(Visitor<R> v) → R
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited