Visitor<T> class
abstract
This abstraction visits every node class variant. Visitors are the staple of this runtime implementation. They can be used to implement semantic checks as well as implement runtimes. Additionally custom visitors c an walk the AST of a program and generate lua bytecode.
- Implementers
Constructors
- Visitor()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitAssignExpr(
AssignExpr assignExpr) → T -
visitAssignMultiExpr(
AssignMultiExpr assignMultiExpr) → T -
visitAST(
AST ast) → T -
visitBinaryExpr(
BinaryExpr expr) → T -
visitBooleanLiteral(
BooleanLiteral boolean) → T -
visitBreakStmt(
BreakStmt stmt) → T -
visitDeclArg(
DeclArg declArg) → T -
visitDeclMultiVar(
DeclMultiVar declMultiVar) → T -
visitDeclVar(
DeclVar declVar) → T -
visitForIterLoopStmt(
ForIterLoopStmt forIterLoopStmt) → T -
visitForLoopStmt(
ForLoopStmt forLoopStmt) → T -
visitFuncExpr(
FuncExpr expr) → T -
visitGotoLabelStmt(
GotoLabelStmt gotoLabelStmt) → T -
visitGotoStmt(
GotoStmt gotoStmt) → T -
visitGroupExpr(
GroupExpr groupExpr) → T -
visitIfStmt(
IfStmt stmt) → T -
visitKeyValStmt(
KeyValStmt keyval) → T -
visitMemoryAccess(
MemoryAccess memoryAccess) → T -
visitNilLiteral(
NilLiteral nil) → T -
visitNotExpr(
NotExpr notExpr) → T -
visitNumberLiteral(
NumberLiteral number) → T -
visitRawExpr(
RawExpr rawExpr) → T -
visitRepeatUntilLoopStmt(
RepeatUntilLoopStmt repeatUntilLoopStmt) → T -
visitReturnStmt(
ReturnStmt expr) → T -
visitSelfExpr(
SelfExpr selfExpr) → T -
visitStringLiteral(
StringLiteral string) → T -
visitTableLiteral(
TableLiteral table) → T -
visitUnaryExpr(
UnaryExpr expr) → T -
visitWhileLoopStmt(
WhileLoopStmt whileLoopStmt) → T
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited