GzBaseNode class abstract

DOT language Graph Viz markup node. Every node is given a unique key from the ever-increasing GzBaseNode.globalKeys counter. This ensures nodes in the Lua AST can be uniquely identified even if they contain similar content. This is utilized by GzBaseNode.stubId. If a node's label is non-empty, then GzBaseNode.stubLabel will construct the expression to set that attribute in DOT language.

GzBaseNode.toString returns the DOT language representation of this node. It must be implemented on all children.

Implementers

Constructors

GzBaseNode({required String id, required List<GzBaseNode> children, String? label, String? color, String? fontColor, String? shape})
label is optional. If null, will become id. Side effect: GzBaseNode.globalKeys is increased by one.

Properties

children List<GzBaseNode>
getter/setter pair
color String?
getter/setter pair
fontColor String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
key int
latefinal
label String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape String?
getter/setter pair
stubAttrs String
Constructs the full attribute DOT lang syntax separated by space.
no setter
stubColor String
Constructs a string stub for the color, if one is provided and non-null.
no setter
stubfontColor String
Constructs a string stub for the fontColor, if one is provided and non-null.
no setter
stubId String
no setter
stubLabel String
Constructs the string stub for the label, if one is provided and non-empty.
no setter
stubShape String
Constructs a string stub for the shape, if one is provided and non-null.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

globalKeys int
getter/setter pair